@@ -30,9 +30,9 @@ class AlarmHandler(object):
 		self._launcher = self._LAUNCHER
 
 	def load_settings(self, config, sectionName):
-		self._recurrence = config.getint(sectionName, "recurrence")
-		self._alarmCookie = config.getint(sectionName, "alarmCookie")
 		try:
+			self._recurrence = config.getint(sectionName, "recurrence")
+			self._alarmCookie = config.getint(sectionName, "alarmCookie")
 			launcher = config.get(sectionName, "notifier")
 			if launcher:
 				self._launcher = launcher
@@ -63,7 +63,7 @@ class AlarmHandler(object):
 
 	def _get_start_time(self, recurrence):
 		now = datetime.datetime.now()
-		startTimeMinute = now.minute + recurrence
+		startTimeMinute = now.minute + 2 * recurrence #2*r for extra safety
 		now.replace(minute=startTimeMinute)
 		timestamp = int(time.mktime(now.timetuple()))
 		return timestamp
