@@ -28,12 +28,15 @@ class Dialpad(object):
 	def __init__(self, widgetTree):
 		self._numberdisplay = widgetTree.get_widget("numberdisplay")
 		self._dialButton = widgetTree.get_widget("dial")
+		self._smsButton = widgetTree.get_widget("sms")
 
 	def enable(self):
 		self._dialButton.set_sensitive(False)
+		self._smsButton.set_sensitive(False)
 
 	def disable(self):
 		self._dialButton.set_sensitive(True)
+		self._smsButton.set_sensitive(True)
 
 	@staticmethod
 	def name():
@@ -58,7 +61,7 @@ class AccountInfo(object):
 		self._clearCookiesButton = widgetTree.get_widget("clearcookies")
 
 		self._notifyCheckbox = widgetTree.get_widget("notifyCheckbox")
-		self._minutesEntry = widgetTree.get_widget("minutesEntry")
+		self._minutesEntryButton = widgetTree.get_widget("minutesEntryButton")
 		self._missedCheckbox = widgetTree.get_widget("missedCheckbox")
 		self._voicemailCheckbox = widgetTree.get_widget("voicemailCheckbox")
 		self._smsCheckbox = widgetTree.get_widget("smsCheckbox")
@@ -68,7 +71,7 @@ class AccountInfo(object):
 		self._clearCookiesButton.set_sensitive(False)
 
 		self._notifyCheckbox.set_sensitive(False)
-		self._minutesEntry.set_sensitive(False)
+		self._minutesEntryButton.set_sensitive(False)
 		self._missedCheckbox.set_sensitive(False)
 		self._voicemailCheckbox.set_sensitive(False)
 		self._smsCheckbox.set_sensitive(False)
@@ -80,7 +83,7 @@ class AccountInfo(object):
 		self._clearCookiesButton.set_sensitive(True)
 
 		self._notifyCheckbox.set_sensitive(True)
-		self._minutesEntry.set_sensitive(True)
+		self._minutesEntryButton.set_sensitive(True)
 		self._missedCheckbox.set_sensitive(True)
 		self._voicemailCheckbox.set_sensitive(True)
 		self._smsCheckbox.set_sensitive(True)
